@@ -9,7 +9,7 @@ void Growth::setSelfDetect()
 
     Parser::extract(d_base, d_selfSD, d_selfMean);
 
-    if (0 <= d_selfSD)
+    if (0 <= d_selfSD)                          // OK if selfSD is positive
         return;
 
     Err::negative();
