@@ -16,7 +16,7 @@ Options::Options()
     if (d_arg.option('V'))
     {
         d_specified[STARTUP] += 'V';
-        imsg.on();    
+        imsg.on();
     }
 
     configOption();                         // set d_config[STARTUP]
@@ -41,8 +41,8 @@ Options::Options()
     if (d_arg.option(&value, 'l'))
         lastCaseOption(value);
 
+    if (d_arg.option(&value, "log"))
+        logOption(value);
+
     setSimulationType();
 }
-
-
-
